What’s new in version 1.1.41
============================
Version available since July 29th 2022


Changes
---------
- method of Iteration class, print, returns a dataframe, more exploitable.
- method of Result class, plotResults, plots one variable per figure with their
bounds as horizontal curves, to help users to debug. It can also print vectorial
inputs and constraints.

Contributors
------------
Lucas Agobert
